#
# spec file for package deepin-session-ui
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2021 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define _name dde-session-ui

Name:           deepin-session-ui
Version:        5.5.24
Release:        1.6
Summary:        Deepin desktop-environment - Session UI module
License:        GPL-3.0-or-later
URL:            https://github.com/linuxdeepin/dde-session-ui
Source0:        https://github.com/linuxdeepin/dde-session-ui/archive/%{version}/%{_name}-%{version}.tar.gz
# PATCH-FIX-UPSTEAM fix-library-path.patch hillwood@opensuse.org
Patch0:         fix-library-path.patch
Group:          System/GUI/Other
BuildRequires:  gtest
BuildRequires:  update-desktop-files
BuildRequires:  deepin-gettext-tools
BuildRequires:  dtkcore
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(dde-dock)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(liblightdm-qt5-3)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(gio-qt)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pam-devel
BuildRequires:  libqt5-linguist
Requires:       deepin-wallpapers
Recommends:     %{name}-lang = %{version}-%{release}

%description
This project include those sub-project:

- deepin-lowpower: The user interface of reminding low power.
- deepin-osd: User interface of on-screen display.
- deepin-hotzone: User interface of setting hot zone.

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}
sed -i 's|lrelease|lrelease-qt5|g' translate_generation.sh
# sed -i 's|/usr/lib/dde-dock|%{_libdir}/dde-dock|' \
# dde-notification-plugin/notifications/notifications.pro
sed -i 's|backgrounds/default_background.jpg|wallpapers/openSUSEdefault/contents/images/1920x1080.jpg|g' \
widgets/fullscreenbackground.cpp tests/dde-welcome/global_util/ut_publicfunc.cpp
sed -i 's|backgrounds/deepin/desktop.jpg|wallpapers/openSUSEdefault/contents/images/1920x1080.jpg|g' \
widgets/fullscreenbackground.cpp tests/dde-welcome/global_util/ut_publicfunc.cpp
sed -i 's/qdbusxml2cpp/qdbusxml2cpp-qt5/g' CMakeLists.txt
#Use Geeko logo instead of deepin
# cp %{SOURCE1} lightdm-deepin-greeter/img/

%build
%cmake -DCMAKE_INSTALL_LIBDIR=%{_libdir}
%cmake_build

%install
%cmake_install
%find_lang %{_name} --with-qt

%files
%license LICENSE
%doc README.md CONTRIBUTING.md CHANGELOG.md
%{_bindir}/*
%{_datadir}/icons/hicolor/scalable/devices/computer.svg
%{_prefix}/lib/deepin-daemon
%dir %{_libdir}/dde-dock
%dir %{_libdir}/dde-dock/plugins
%{_libdir}/dde-dock/plugins/libnotifications.so
%dir %{_datadir}/dde-session-ui
%dir %{_datadir}/dde-session-ui/translations
%{_datadir}/dbus-1/services/com.deepin.dde.welcome.service
%{_datadir}/dbus-1/services/com.deepin.dde.osd.service
%{_datadir}/dbus-1/services/com.deepin.dde.Notification.service
%{_datadir}/dbus-1/services/com.deepin.dde.freedesktop.Notification.service
%{_datadir}/dbus-1/services/com.deepin.dde.MemoryWarningDialog.service
%{_datadir}/dbus-1/services/com.deepin.dde.WarningDialog.service
%{_datadir}/glib-2.0/schemas/com.deepin.dde.dock.module.notifications.gschema.xml

%files lang -f %{_name}.lang
%dir %{_datadir}/%{_name}
%dir %{_datadir}/%{_name}/translations
%{_datadir}/%{_name}/translations/dde-session-ui.qm
%if 0%{?suse_version} <= 1500
%{_datadir}/%{_name}/translations/%{_name}_ast.qm
%{_datadir}/%{_name}/translations/%{_name}_fil.qm
%{_datadir}/%{_name}/translations/%{_name}_pam.qm
%endif

%changelog
* Tue Jun 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.24
  * Fix a crash bug on wayland
* Sat May  7 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.23
  * Fix bugs
* Wed Apr  6 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.10
  * Migrate to cmake
  * Fix bugs
- Add fix-library-path.patch
* Tue Feb 15 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.6
  * Add AccessibleName of widget
  * Add dde-hints-dialog
  * Fix bugs
  * Update translations
* Mon Jan 31 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix filelist for Leap 15
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.53
  * Fix bug
  * Add the icon for Flght mode
  * Optimize mute OSD
* Mon Nov  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build: do not package translations in main and -lang package.
* Wed Oct 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix filelist
* Sun Oct 24 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.31
  * Add AccessibleName
  * Fix bugs
* Sun Sep 19 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.29
  * Disable AccessibleName check by default
  * Optimize test modules
  * Add AccessibleName for widgets
  * Fix bugs
* Mon Jul 26 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.20
  * Optimize HiDPI features
  * Fix bugs
  * Add show and hide interfaces
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.4.7
  * Fix: Modify the Do-Not-Disturb mode logic
  * Fix(OSD): Move the edge of the notification center to the right
  * Added show- and hide- functions for dde-session-daemon to
    handle single-finger sliding of the notification center
* Thu May  6 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.6
  * Fix bug
  * Add test
* Fri Apr 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.5
  * Fix bugs
* Wed Feb 24 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.35
  * Update dbus api
  * feat: Initial packit setup
  * Remove some headers
  * Fix bugs
* Tue Aug 13 2019 Hillwood Yang <hillwood@opensuse.org>
- Use suse information in lightdm-deepin-greeter (use-suse-info.patch)
* Thu Jul 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.9.14
  * Fix shutdown: not hide hibernate button when show again
  * Fix lock: unlock when fake nopassword user
  * Fix replace deepin_qt to dtk_qmake
  * Fix lock: fake nopassword user when user not have password
  * Fix greeter: update user list
  * Fix shutdown: solve the problem caused by rebase again
  * Fix user avatar not show
  * Fix greeter:missing blurdone signal, wrong set user keyboard layout, not
    show fprint pam info
  * Fix lock: when user unlock not reset checkpasswd num, cannot reboot system
  * Fix shutdown: when inhibitwarningview show after system monitor button
    cannot enter hover state, multiuser warning tips are truncated
  * create document
  * split config files
  * support not init native user
  * init LDAP user is first
  * Add ShowSwitchUserButton by [always|ondemand|disabled]
  * Add login box does not display avatar
  * Add LDAP login switch button
  * Support set monitor config when release meta key
  * Fix crash in refreshInputState when m_user is null
  * Fix not select user last use session
  * Fix greeter: Prevent failures caused by authentication at startup
  * Fux greeter: session list position not align center
  * Fix No focus after closing login lock
  * Fix not auth user when show again
  * Fix crash when show inhibitwarnview again
  * Fix missing unlock mutex
  * Fix not sync multi-screen user lock info
  * can always auth user
  * show error at first time
  * shutdown fprintd device for the first time
  * greeter: use new dpi scale ratio config
  * Fix nopasswdlogin cannot unlock
  * Fix not refresh nopasswordlogin when show again
* Sun May  5 2019 Hillwood Yang <hillwood@opensuse.org>
- Install lightdm.conf
* Mon Apr 22 2019 Hillwood Yang <hillwood@opensuse.org>
- Fix filelist
* Tue Apr 16 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.9.2
  * support deepin-auth
  * Fix greeter: support multi screen scale ratio
  * Fix missing deepin-qtconfig
  * Fix not check swap again
  * Fix screen copy mode will empty page
  * Fix missing memory header
  * Fix dde-lowpower: missing c++11 cxxflags
  * Fix greeter: mulit-user fingerprint login
  * Fix multi-screen data sync
  * Fix translation error
  * lock and greeter support disable sleep button for shutdownpage
  * support config file to control function
  * support use config value to control sleep button
  * inhibitwarning support data sync
  * etc... Please view CHANGELOG.md to get more changes.
* Fri Mar 23 2018 hillwood@opensuse.org
- Update version to 4.3.2
  * Fix many bugs and update features. Please see CHANGELOG.md
    to get more detail.
* Mon Dec  4 2017 hillwood@opensuse.org
- Add Geeko logo for lightdm-deepin-greeter.
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 4.1.7
  * Fix unable to login other desktop when user is nopassword
  * Fix error auth password when nopassword user
  * Fix don't show alert when user is nopasswdlogin
  * Fix cannot open system monitor
  * Change hide time to 1 second
  * Fix background white
  * Fix refresh wallpaper when not the same file
  * Fix some widget shown too early
  * Fix skip when click self
  * Fix userwidget pos error when size changed
  * Add dde-dman-portal
  * Support display user displayname
  * Support display user fullname
  * Login user interface updated
  * Fix nopasswordlogin function failure
  * Fix use dgettext update ts with fprint
  * Fix set default background when get blur error
  * Fix osd support multiple screens list
  * Fix switch user will login
  * Fix window placed at wrong position
  * Fix update ts with fprint
  * Fix support dapplication single instance
  * Fix scroll to current item when direct switch
  * Use blur image dbus
  * Adding detection rules
  * Use dapplication and set default theme
  * Apply system font size settings
  * Fix not show error message when finger verification
  * Fix show wrong passwd premature
  * Fix cannot scroll when error index
  * Fix not grab keyboard
  * Fix white screen when not use deepin wm
  * Fix not disable hotzone when show
  * Fix svg file error
  * Fix correct header filename
  * Fix upgrade success not load ts
  * Fix remove libpam0g from debian/control
  * Fix shutdown contentwidget not init
  * Add finger verification timed out tip
* Mon Nov 13 2017 hillwood@opensuse.org
- Cleanup spec.
  * Use %%suse_update_desktop_file macro.
  * Fix desktop file.
  * Add Group tag.
- Split language package.
- Split deepin-lowpower, deepin-osd, deepin-switchtogreeter, deepin-shutdown,
  deepin-lock and deepin-hotzone.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
